
<?php
/* Copyright (C) 2020 SuperAdmin <contact@lalis.fr>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * \file    core/triggers/interface_99_modOutilsLalis_OutilsLalisTriggers.class.php
 * \ingroup outilslalis
 * \brief   Example trigger.
 *
 * Put detailed description here.
 *
 * \remarks You can create other triggers by copying this one.
 * - File name should be either:
 *      - interface_99_modOutilsLalis_MyTrigger.class.php
 *      - interface_99_all_MyTrigger.class.php
 * - The file must stay in core/triggers
 * - The class name must be InterfaceMytrigger
 * - The constructor method must be named InterfaceMytrigger
 * - The name property name must be MyTrigger
 */

require_once DOL_DOCUMENT_ROOT.'/core/triggers/dolibarrtriggers.class.php';


/**
 *  Class of triggers for OutilsLalis module
 */
class InterfaceOutilsLalisTriggers extends DolibarrTriggers
{
	/**
	 * @var DoliDB Database handler
	 */
	protected $db;

	/**
	 * Constructor
	 *
	 * @param DoliDB $db Database handler
	 */
	public function __construct($db)
	{
		$this->db = $db;

		$this->name = preg_replace('/^Interface/i', '', get_class($this));
		$this->family = "demo";
		$this->description = "OutilsLalis triggers.";
		// 'development', 'experimental', 'dolibarr' or version
		$this->version = 'development';
		$this->picto = 'outilslalis@outilslalis';
	}

	/**
	 * Trigger name
	 *
	 * @return string Name of trigger file
	 */
	public function getName()
	{
		return $this->name;
	}

	/**
	 * Trigger description
	 *
	 * @return string Description of trigger file
	 */
	public function getDesc()
	{
		return $this->description;
	}


	/**
	 * Function called when a Dolibarrr business event is done.
	 * All functions "runTrigger" are triggered if file
	 * is inside directory core/triggers
	 *
	 * @param string 		$action 	Event action code
	 * @param CommonObject 	$object 	Object
	 * @param User 			$user 		Object user
	 * @param Translate 	$langs 		Object langs
	 * @param Conf 			$conf 		Object conf
	 * @return int              		<0 if KO, 0 if no triggered ran, >0 if OK
	 */
	public function runTrigger($action, $object, User $user, Translate $langs, Conf $conf)
	{
        if (empty($conf->outilslalis->enabled)) return 0;     // Module not active, we do nothing

// Put here code you want to execute when a Dolibarr business events occurs.
		// Data and type of action are stored into $object and $action
        switch ($action) {

// Users
		    //case 'USER_CREATE':
		    //case 'USER_MODIFY':
		    //case 'USER_NEW_PASSWORD':
		    //case 'USER_ENABLEDISABLE':
		    //case 'USER_DELETE':
		    //case 'USER_SETINGROUP':
		    //case 'USER_REMOVEFROMGROUP':

		    // Contacts
		    //case 'CONTACT_CREATE':
		    //case 'CONTACT_MODIFY':
		    //case 'CONTACT_DELETE':
		    //case 'CONTACT_ENABLEDISABLE':

		    // Donation
		    //case 'DON_CREATE':
		    //case 'DON_UPDATE':
		    //case 'DON_DELETE':

		    // Interventions
		    //case 'FICHINTER_CREATE':
		    //case 'FICHINTER_MODIFY':
		    //case 'FICHINTER_VALIDATE':
		    //case 'FICHINTER_DELETE':
		    //case 'LINEFICHINTER_CREATE':
		    //case 'LINEFICHINTER_UPDATE':
		    //case 'LINEFICHINTER_DELETE':

		    // Members
		    case 'MEMBER_CREATE':
				include "nouveau_membre.php";
				sync2contacts($user, $object);
				sync2nextcloud(INSERT, $user, $object);

		    break;
		    //case 'MEMBER_VALIDATE':
		    //break;
		    //case 'MEMBER_SUBSCRIPTION':
		    case 'MEMBER_MODIFY':
				include "nouveau_membre.php";
				sync2contacts($user, $object);
				sync2nextcloud(UPDATE, $user, $object);

		    break;
		    //case 'MEMBER_NEW_PASSWORD':
		    //case 'MEMBER_RESILIATE':
		    //break;

		    case 'MEMBER_DELETE':
				include "nouveau_membre.php";
				delete_contact($object);
			break;
		    default:
		        dol_syslog("Trigger '".$this->name."' for action '$action' launched by ".__FILE__.". id=".$object->id);
		    break;
		}
		return 1;
	}
}
